ChangeLog
=========

0.0.2 - 2016/10/14
==================

- support for groupby.
- add main object definition in the main package.
- add translator in the crudannotation.

0.0.1 - 2016/10/14
==================

- library creation.
